# User (and group) name under which the Tor daemon runs.

%define toruser tor
%define torgroup tor

## Target a specific arch and OS
#
# default is i686 linux
#%define target gnu
#%define target_cpu i686
#%define target_os linux

#%define localstatedir /var/local

Distribution:   CCux-Linux
Packager:	Karsten Brockmann <arcam@ccux-linux.com>

Name:		tor
Summary:        Anonymizing overlay network for TCP (The onion router)
Version:	0.1.2.14
Release:	1
Provides:	%{name}
License:	BSD-like
URL:		http://tor.eff.org/
Group:		Networking/Other
Source0:	%{name}-%{version}.tar.gz
Patch0:		tor-initscript.patch
BuildRoot:	%{_tmppath}/%{name}-buildroot
BuildRequires:  glibc-devel
BuildRequires:  openssl-devel
BuildRequires:  libevent-devel
BuildRequires:  zlib-devel

%description
Tor is a connection-based low-latency anonymous communication system.

This package provides the "tor" program, which serves as both a client and
a relay node. Scripts will automatically create a "%{toruser}" user and
a "%{torgroup}" group, and set tor up to run as a daemon when the system
is rebooted.

Applications connect to the local Tor proxy using the SOCKS
protocol. The local proxy chooses a path through a set of relays, in
which each relay knows its predecessor and successor, but no
others. Traffic flowing down the circuit is unwrapped by a symmetric
key at each relay, which reveals the downstream relay.

Warnings: Tor does no protocol cleaning.  That means there is a danger
that application protocols and associated programs can be induced to
reveal information about the initiator. Tor depends on Privoxy and
similar protocol cleaners to solve this problem. This is alpha code,
and is even more likely than released code to have anonymity-spoiling
bugs. The present network is very small -- this further reduces the
strength of the anonymity provided. Tor is not presently suitable


%pre
# If tor is already installed and running (whether installed by RPM
# or not), then kill it, but remember that it was running.
rm -f /%{_localstatedir}/tmp/${name}-was-running-%{version}-%{release}
if [ -f %{_initrddir}/%{name} ] && /etc/rc.d/init.d/%{name} status ; then
    /etc/rc.d/init.d/%{name} stop
    touch /%{_localstatedir}/tmp/${name}-was-running-%{version}-%{release}
fi

#
# Create a user and group if need be
#
if [ ! -n "`/usr/bin/id -g %{torgroup} 2>/dev/null`" ]; then
    /usr/sbin/groupadd --gid 210 %{torgroup} 2> /dev/null || :
fi
if [ ! -n "`/usr/bin/id -u %{toruser} 2>/dev/null`" ]; then
    /usr/sbin/useradd -g %{torgroup} -d %{_localstatedir}/lib/%{name} -s %{_sbindir}/nologin --uid 210 %{toruser} 2> /dev/null || :
fi

%post
ldconfig
# If this is a new installation, use chkconfig to put tor in the
# default set of runlevels. If it's an upgrade, leave the existing
# configuration alone.
if [ $1 -eq 1 ]; then
    /sbin/chkconfig --add %{name}
    /sbin/chkconfig %{name} on
fi

# Make sure the runtime data have the right ownership.
chown -R %{toruser}  %{_localstatedir}/{lib,log,run}/%{name}
chgrp -R %{torgroup} %{_localstatedir}/{lib,log,run}/%{name}

if [ -f /%{_localstatedir}/tmp/${name}-was-running-%{version}-%{release} ]; then
    /etc/rc.d/init.d/%{name} start
    rm -f /%{_localstatedir}/tmp/${name}-was-running-%{version}-%{release}
fi

%preun
# If no instances of tor will be installed when we're done, make
# sure that it gets killed. We *don't* want to kill it or delete
# any of its data on uninstall if it's being upgraded to a new
# version, because the new version will actually already have
# been installed and started before the uninstall script for
# the old version is run, and we'd end up hosing it.
if [ $1 -le 0 ]; then
    if [ -f %{_initrddir}/%{name} ] && /sbin/service %{name} status ; then
        /etc/rc.d/init.d/%{name} stop
    fi
    /sbin/chkconfig --del %{name}
    rm -f ${_localstatedir}/lib/%{name}/cached-directory
    rm -f ${_localstatedir}/lib/%{name}/bw_accounting
    rm -f ${_localstatedir}/lib/%{name}/control_auth_cookie
    rm -f ${_localstatedir}/lib/%{name}/router.desc
    rm -f ${_localstatedir}/lib/%{name}/fingerprint
fi
exit 0


%postun
ldconfig

%prep
%setup -n %{name}-%{version}
%patch0 -p1

%build
./configure 	--prefix=%_prefix \
		--sysconfdir=%_sysconfdir \
		--mandir=%_mandir \
		--localstatedir=%_localstatedir \
		--with-tor-user=%{toruser} \
		--with-tor-group=%{torgroup} 
#        	--build=%{_host} \
#		--host=%{_host} \
#		--target=%{_host}
make

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR="$RPM_BUILD_ROOT"
find %{buildroot} -type f -exec /usr/bin/strip --strip-debug '{}' ';'

# Install init script and control script
mkdir -p ${RPM_BUILD_ROOT}%{_initrddir}
install -p -m 755 contrib/tor.sh ${RPM_BUILD_ROOT}%{_initrddir}/%{name}
install -p -m 755 contrib/torctl ${RPM_BUILD_ROOT}%{_bindir}

# Set up config file; "sample" file implements a basic user node.
install -p -m 644 ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/torrc.sample ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/torrc

# Install the logrotate control file.
mkdir -p -m 755 ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d
install -p -m 644 contrib/tor.logrotate ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{name}

# Directories that don't have any preinstalled files
mkdir -p -m 700 ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}
mkdir -p -m 755 ${RPM_BUILD_ROOT}%{_localstatedir}/run/%{name}
mkdir -p -m 755 ${RPM_BUILD_ROOT}%{_localstatedir}/log/%{name}
#mkdir -p -m 700 ${RPM_BUILD_ROOT}%{_localstatedir}/tmp/%{name}



%files
%defattr(-,root,root)
%_bindir
%_localstatedir
%_mandir
%_sysconfdir

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Sat May 26 2007 Karsten Brockmann <arcam@ccux-linux.de> 0.1.2.14-1
- Version update
* Tue May 15 2007 Karsten Brockmann <arcam@ccux-linux.de> 0.1.2.13-1
- Initial package release
